#ifndef NT2_INCLUDE_CONSTANTS_MINF_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MINF_HPP_INCLUDED

#include <nt2/constant/include/constants/minf.hpp>

#endif
